Summary:       Scientific Tools for Python
Name:          scipy
Version:       1.7.3
Release:       6%{?dist}
License:       BSD and Boost and Public Domain
Url:           http://www.scipy.org/scipylib/index.html
Source0:       https://github.com/scipy/scipy/releases/download/v%{version}/scipy-%{version}.tar.gz

Patch0001:     fix-the-pytest-decorator-for-conditional-skipping.patch

BuildRequires:  gcc-gfortran swig gcc-c++
BuildRequires:  fftw-devel suitesparse-devel flexiblas-devel flexiblas-netlib qhull-devel
BuildRequires:  /usr/bin/pathfix.py
BuildRequires:  python3-pybind11 >= 2.4.0
BuildRequires:  python3-numpy python3-devel python3-numpy-f2py python3-setuptools python3-Cython
BuildRequires:  pybind11-devel python3-pytest python3-pytest-xdist python3-pytest-timeout

%description 
Scipy is open-source software for mathematics, science, and engineering.
The core library is NumPy which provides convenient and fast N-dimensional
array manipulation. The SciPy library is built to work with NumPy arrays,
and provides many user-friendly and efficient numerical routines such as
routines for numerical integration and optimization. Together, they run
on all popular operating systems, are quick to install, and are free of
charge. NumPy and SciPy are easy to use, but powerful enough to be depended
upon by some of the world's leading scientists and engineers.


%package -n python3-scipy
Summary:    Scientific Tools for Python
Requires:   python3-numpy python3-f2py
Provides:   python3-scipy = %{version}-%{release}

%description -n python3-scipy 
Scipy is open-source software for mathematics, science, and engineering.
The core library is NumPy which provides convenient and fast N-dimensional
array manipulation. The SciPy library is built to work with NumPy arrays,
and provides many user-friendly and efficient numerical routines such as
routines for numerical integration and optimization. Together, they run
on all popular operating systems, are quick to install, and are free of
charge. NumPy and SciPy are easy to use, but powerful enough to be depended
upon by some of the world's leading scientists and engineers.

%prep
%autosetup -p1 -n %{name}-%{version}
cat > site.cfg << EOF

[amd]
library_dirs = %{_libdir}
include_dirs = /usr/include/suitesparse
amd_libs = amd

[umfpack]
library_dirs = %{_libdir}
include_dirs = /usr/include/suitesparse
umfpack_libs = umfpack

[openblas]
libraries = flexiblas
library_dirs = %{_libdir}
EOF

sed -i 's/metadata = dict(/metadata = dict(package_data={"": ["*.dat"]},/' setup.py
rm doc/sphinxext -r
rm $(grep -rl '/\* Generated by Cython') PKG-INFO


%build
export SCIPY_USE_PYTHRAN=0

for PY in %{python3_version}; do
  env CFLAGS="%{optflags} -lm" \
    FFLAGS="%{optflags} -fPIC -fallow-argument-mismatch" \
    LDFLAGS="%{__global_ldflags}" \
    %{_bindir}/python$PY setup.py config_fc \
    --fcompiler=gnu95 --noarch \
    build
done


%install
export SCIPY_USE_PYTHRAN=0

%py3_install
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" %{buildroot}%{python3_sitearch}


%check
export FLEXIBLAS=netlib
TIMEOUT=500
export PYTEST_ADDOPTS="-k 'not TestSchur'"

%ifarch aarch64
export PYTEST_ADDOPTS="-k 'not TestSchur and not test_solve_discrete_are'"
%endif

%ifarch x86_64
export PYTEST_ADDOPTS="-k 'not TestSchur and not test_sygst'"
%endif

%ifnarch ppc64le || x86_64
pushd %{buildroot}/%{python3_sitearch}
%{pytest} --timeout=${TIMEOUT} scipy --numprocesses=auto
rm -rf gram{A,B}
popd
%endif


%files -n python3-scipy
%license LICENSE.txt
%{python3_sitearch}/scipy/
%{python3_sitearch}/*.egg-info


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.3-6
- Rebuilt for OpenCloudOS Stream 23.05

* Mon Apr 03 2023 Miaojun Dong <zoedong@tencent.com> - 1.7.3-5
- fix the pytest decorator for conditional skipping

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.3-4
- Rebuilt for OpenCloudOS Stream 23

* Thu Feb 09 2023 Miaojun Dong <zoedong@tencent.com> - 1.7.3-3
- Update date in changelog

* Thu Feb 09 2023 Miaojun Dong <zoedong@tencent.com> - 1.7.3-2
- Add buildrequires flexiblas-netlib

* Thu Nov 17 2022 Miaojun Dong <zoedong@tencent.com> - 1.7.3-1
- Initial build
